==> Phenyx-Utils-0.0.3.tar.gz: Phenyx-Utils-0.0.3/lib/Phenyx/Utils.pm <==
package Phenyx::Utils;

use warnings;
use strict;

=head1 NAME

Phenyx::Utils

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.0.3';

=head1 DESCRIPTION

A set of utilities developped by the Phenyx team (www.genebio.com), but not linked to the main project (meaning you should be able to use them without any reference to a core Phenyx module)

Topics covered:

=over 4

=item LSF submission in Phenyx::Utils::LSF::Submission and Phenyx::Utils::LSF::JobInfo

=back

=head1 SYNOPSIS


=head1 EXPORT


=head1 FUNCTIONS


=head1 BUGS

Please report any bugs or feature requests to
C<bug-phenyx-utils@rt.cpan.org>, or through the web interface at
L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Phenyx-Utils>.
I will be notified, and then you'll automatically be notified of progress on
your bug as I make changes.

=head1 SEE ALSO

Phenyx::Utils::LSF::Submission

=head1 ACKNOWLEDGEMENTS

=head1 COPYRIGHT

Copyright (C) 2004-2005  Geneva Bioinformatics www.genebio.com

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

=head1 AUTHORS

Alexandre Masselot, www.genebio.com

=cut

1; # End of Phenyx::Utils

==> Phenyx-Utils-0.01.tar.gz: Phenyx-Utils-0.01/lib/Phenyx/Utils.pm <==
package Phenyx::Utils;

use warnings;
use strict;

=head1 NAME

Phenyx::Utils

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';

=head1 DESCRIPTION

A set of utilities developped by the Phenyx team (www.genebio.com), but not linked to the main project (meaning you should be able to use them without any reference to a core Phenyx module)

Topics covered:

=over 4

=item LSF submission in Phenyx::Utils::LSF::Submission and Phenyx::Utils::LSF::JobInfo

=back

=head1 SYNOPSIS


=head1 EXPORT


=head1 FUNCTIONS


=head1 BUGS

Please report any bugs or feature requests to
C<bug-phenyx-utils@rt.cpan.org>, or through the web interface at
L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Phenyx-Utils>.
I will be notified, and then you'll automatically be notified of progress on
your bug as I make changes.

=head1 SEE ALSO

Phenyx::Utils::LSF::Submission

=head1 ACKNOWLEDGEMENTS

=head1 COPYRIGHT

Copyright (C) 2004-2005  Geneva Bioinformatics www.genebio.com

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

=head1 AUTHORS

Alexandre Masselot, www.genebio.com

=cut

1; # End of Phenyx::Utils
